@@ -37,7 +37,8 @@ class RevAiAPIClient(BaseClient):
         BaseClient.__init__(self, access_token)
 
     def submit_job_url(
-            self, media_url,
+            self,
+            media_url,
             metadata=None,
             callback_url=None,
             skip_diarization=False,
@@ -48,7 +49,12 @@ class RevAiAPIClient(BaseClient):
             remove_disfluencies=False,
             delete_after_seconds=None,
             language=None,
-            custom_vocabulary_id=None):
+            custom_vocabulary_id=None,
+            transcriber=None,
+            verbatim=None,
+            rush=None,
+            test_mode=None,
+            segments_to_transcribe=None):
         """Submit media given a URL for transcription.
         The audio data is downloaded from the URL.
 
@@ -78,6 +84,15 @@ class RevAiAPIClient(BaseClient):
         :param custom_vocabulary_id: The id of a pre-completed custom vocabulary
             submitted through the custom vocabularies api. Cannot be used with the
             custom_vocabularies parameter.
+        :param transcriber: type of transcriber to use to transcribe the media file
+        :param verbatim: Only available with "human" transcriber.
+            Whether human transcriber transcribes every syllable.
+        :param rush: Only available with "human" transcriber.
+            Whether job is given higher priority to be worked on sooner for higher pricing.
+        :param test_mode: Only available with "human" transcriber.
+            Whether human transcription job is mocked and no transcription actually happens.
+        :param segments_to_transcribe: Only available with "human" transcriber.
+            Sections of transcript needed to be transcribed.
         :returns: raw response data
         :raises: HTTPError
         """
@@ -88,7 +103,9 @@ class RevAiAPIClient(BaseClient):
                                                    skip_punctuation, speaker_channels_count,
                                                    custom_vocabularies, filter_profanity,
                                                    remove_disfluencies, delete_after_seconds,
-                                                   language, custom_vocabulary_id)
+                                                   language, custom_vocabulary_id, transcriber,
+                                                   verbatim, rush, test_mode,
+                                                   segments_to_transcribe)
 
         response = self._make_http_request(
             "POST",
@@ -99,7 +116,8 @@ class RevAiAPIClient(BaseClient):
         return Job.from_json(response.json())
 
     def submit_job_local_file(
-            self, filename,
+            self,
+            filename,
             metadata=None,
             callback_url=None,
             skip_diarization=False,
@@ -110,7 +128,12 @@ class RevAiAPIClient(BaseClient):
             remove_disfluencies=False,
             delete_after_seconds=None,
             language=None,
-            custom_vocabulary_id=None):
+            custom_vocabulary_id=None,
+            transcriber=None,
+            verbatim=None,
+            rush=None,
+            test_mode=None,
+            segments_to_transcribe=None):
         """Submit a local file for transcription.
         Note that the content type is inferred if not provided.
 
@@ -140,6 +163,15 @@ class RevAiAPIClient(BaseClient):
         :param custom_vocabulary_id: The id of a pre-completed custom vocabulary
             submitted through the custom vocabularies api. Cannot be used with the
             custom_vocabularies parameter.
+        :param transcriber: type of transcriber to use to transcribe the media file
+        :param verbatim: Only available with "human" transcriber.
+            Whether human transcriber transcribes every syllable.
+        :param rush: Only available with "human" transcriber.
+            Whether job is given higher priority to be worked on sooner for higher pricing.
+        :param test_mode: Only available with "human" transcriber.
+            Whether human transcription job is mocked and no transcription actually happens.
+        :param segments_to_transcribe: Only available with "human" transcriber.
+            Sections of transcript needed to be transcribed.
         :returns: raw response data
         :raises: HTTPError
         """
@@ -150,7 +182,9 @@ class RevAiAPIClient(BaseClient):
                                                    skip_punctuation, speaker_channels_count,
                                                    custom_vocabularies, filter_profanity,
                                                    remove_disfluencies, delete_after_seconds,
-                                                   language, custom_vocabulary_id)
+                                                   language, custom_vocabulary_id, transcriber,
+                                                   verbatim, rush, test_mode,
+                                                   segments_to_transcribe)
 
         with open(filename, 'rb') as f:
             files = {
@@ -391,7 +425,12 @@ class RevAiAPIClient(BaseClient):
             remove_disfluencies=None,
             delete_after_seconds=None,
             language=None,
-            custom_vocabulary_id=None):
+            custom_vocabulary_id=None,
+            transcriber=None,
+            verbatim=None,
+            rush=None,
+            test_mode=None,
+            segments_to_transcribe=None):
         payload = {}
         if media_url:
             payload['media_url'] = media_url
@@ -418,6 +457,16 @@ class RevAiAPIClient(BaseClient):
             payload['language'] = language
         if custom_vocabulary_id:
             payload['custom_vocabulary_id'] = custom_vocabulary_id
+        if transcriber:
+            payload['transcriber'] = transcriber
+        if verbatim:
+            payload['verbatim'] = verbatim
+        if rush:
+            payload['rush'] = rush
+        if test_mode:
+            payload['test_mode'] = test_mode
+        if segments_to_transcribe:
+            payload['segments_to_transcribe'] = segments_to_transcribe
         return payload
 
     def _create_captions_query(self, speaker_channel):
