@@ -23,6 +23,7 @@ JOBS_URL = urljoin(RevAiAPIClient.base_url, 'jobs')
 CUSTOM_VOCAB = [{"phrases": ["word one", "word two"]}]
 CUSTOM_VOCAB_ID = "vid"
 LANGUAGE = 'en'
+TRANSCRIBER = 'machine_v2'
 
 
 @pytest.mark.usefixtures('mock_session', 'make_mock_response')
@@ -111,7 +112,8 @@ class TestJobEndpoints():
             'filter_profanity': True,
             'remove_disfluencies': True,
             'delete_after_seconds': 0,
-            'language': LANGUAGE
+            'language': LANGUAGE,
+            'transcriber': TRANSCRIBER
         }
         response = make_mock_response(url=JOB_ID_URL, json_data=data)
         mock_session.request.return_value = response
@@ -120,13 +122,22 @@ class TestJobEndpoints():
         res = client.submit_job_url(MEDIA_URL, METADATA,
                                     CALLBACK_URL, True,
                                     True, 1, CUSTOM_VOCAB, True,
-                                    True, 0, LANGUAGE, CUSTOM_VOCAB_ID)
+                                    True, 0, LANGUAGE, CUSTOM_VOCAB_ID,
+                                    TRANSCRIBER)
 
         assert res == Job(JOB_ID,
                           CREATED_ON,
                           JobStatus.IN_PROGRESS,
                           metadata=METADATA,
-                          callback_url=CALLBACK_URL)
+                          callback_url=CALLBACK_URL,
+                          skip_punctuation=True,
+                          skip_diarization=True,
+                          speaker_channels_count=1,
+                          filter_profanity=True,
+                          remove_disfluencies=True,
+                          delete_after_seconds=0,
+                          language=LANGUAGE,
+                          transcriber=TRANSCRIBER)
         mock_session.request.assert_called_once_with(
             "POST",
             JOBS_URL,
@@ -142,7 +153,44 @@ class TestJobEndpoints():
                 'remove_disfluencies': True,
                 'delete_after_seconds': 0,
                 'language': LANGUAGE,
-                'custom_vocabulary_id': CUSTOM_VOCAB_ID
+                'custom_vocabulary_id': CUSTOM_VOCAB_ID,
+                'transcriber': TRANSCRIBER
+            },
+            headers=client.default_headers)
+
+    def test_submit_job_url_with_human_transcription_and_success(self, mock_session, make_mock_response):
+        segments = [{
+            'start': 1.0,
+            'end': 2.0
+        }]
+        data = {
+            'id': JOB_ID,
+            'status': 'in_progress',
+            'created_on': CREATED_ON,
+            'transcriber': 'human',
+            'verbatim': True,
+            'segments_to_transcribe': segments
+        }
+        response = make_mock_response(url=JOB_ID_URL, json_data=data)
+        mock_session.request.return_value = response
+        client = RevAiAPIClient(TOKEN)
+
+        res = client.submit_job_url(MEDIA_URL, transcriber='human', verbatim=True, rush=False, segments_to_transcribe=segments)
+
+        assert res == Job(JOB_ID,
+                          CREATED_ON,
+                          JobStatus.IN_PROGRESS,
+                          transcriber='human',
+                          verbatim=True,
+                          segments_to_transcribe=segments)
+        mock_session.request.assert_called_once_with(
+            'POST',
+            JOBS_URL,
+            json={
+                'media_url': MEDIA_URL,
+                'transcriber': 'human',
+                'verbatim': True,
+                'segments_to_transcribe': segments
             },
             headers=client.default_headers)
 
@@ -165,7 +213,8 @@ class TestJobEndpoints():
             'filter_profanity': True,
             'remove_disfluencies': True,
             'delete_after_seconds': 0,
-            'language': LANGUAGE
+            'language': LANGUAGE,
+            'transcriber': TRANSCRIBER
         }
         response = make_mock_response(url=JOB_ID_URL, json_data=data)
         mock_session.request.return_value = response
@@ -175,13 +224,22 @@ class TestJobEndpoints():
             res = client.submit_job_local_file(FILENAME, METADATA,
                                                CALLBACK_URL, True,
                                                True, 1, CUSTOM_VOCAB, True,
-                                               True, 0, LANGUAGE, CUSTOM_VOCAB_ID)
+                                               True, 0, LANGUAGE, CUSTOM_VOCAB_ID,
+                                               TRANSCRIBER)
 
             assert res == Job(JOB_ID,
                               CREATED_ON,
                               JobStatus.IN_PROGRESS,
                               metadata=METADATA,
-                              callback_url=CALLBACK_URL)
+                              callback_url=CALLBACK_URL,
+                              skip_punctuation=True,
+                              skip_diarization=True,
+                              speaker_channels_count=1,
+                              filter_profanity=True,
+                              remove_disfluencies=True,
+                              delete_after_seconds=0,
+                              language=LANGUAGE,
+                              transcriber=TRANSCRIBER)
             mock_session.request.assert_called_once_with(
                 "POST",
                 JOBS_URL,
@@ -200,7 +258,8 @@ class TestJobEndpoints():
                             'remove_disfluencies': True,
                             'delete_after_seconds': 0,
                             'language': LANGUAGE,
-                            'custom_vocabulary_id': CUSTOM_VOCAB_ID
+                            'custom_vocabulary_id': CUSTOM_VOCAB_ID,
+                            'transcriber': TRANSCRIBER
                         }, sort_keys=True)
                     )
                 },
